@@ -1,20 +1,45 @@
+#  File ergm/R/ergm.getmodel.R
+#  Part of the statnet package, http://statnetproject.org
+#
+#  This software is distributed under the GPL-3 license.  It is free,
+#  open source, and has the attribution requirements (GPL Section 7) in
+#    http://statnetproject.org/attribution
+#
+# Copyright 2003 Mark S. Handcock, University of Washington
+#                David R. Hunter, Penn State University
+#                Carter T. Butts, University of California - Irvine
+#                Steven M. Goodreau, University of Washington
+#                Martina Morris, University of Washington
+# Copyright 2007 The statnet Development Team
+######################################################################
 ergm.getmodel <- function (formula, nw, silent=FALSE, ...) {
   # Parse the formula, create an object of class "model.ergm" that contains
   # all relevant information about the model.  As part of this job, call the
   # appropriate InitErgm functions.
   if ((dc<-data.class(formula)) != "formula")
     stop (paste("Invalid formula of class ",dc), call.=FALSE)
-  trms<-terms(formula)
-  if (trms[[1]]!="~")
+
+  if (formula[[1]]!="~")
     stop ("Formula must be of the form 'network ~ model'.", call.=FALSE)  
-  v <- attr(trms, "variables")
-  if (length(v) < 3) 
-    stop(paste("No model specified for network ", trms[[2]]), call.=FALSE)
+  
+  if (length(formula) < 3) 
+    stop(paste("No model specified for network ", formula[[2]]), call.=FALSE)
+
+  v<-list()
+  rhs<-formula[[3]]
+  while(length(rhs)==3 && rhs[[1]]=="+"){ # i.e. list(`+`, all but last summand, last summand)
+    v<-c(rhs[[3]],v) # store the last summand
+    rhs<-rhs[[2]] # "recurse" into the all but last summands
+  }
+  v<-c(rhs,v)
+  
+  formula.env<-environment(formula)
+  
   model <- structure(list(formula=formula, node.attrib = NULL, coef.names = NULL,
                       offset = NULL,
                       terms = NULL, networkstats.0 = NULL, etamap = NULL),
                  class = "model.ergm")
-  for (i in 3:length(v)) {
+  for (i in 1:length(v)) {
     if (is.call(v[[i]])) { # This term has some arguments
       if(v[[i]][[1]] == "offset"){
         if(length(v[[i]][[2]]) <= 1){
@@ -29,12 +54,12 @@ ergm.getmodel <- function (formula, nw, silent=FALSE, ...) {
       args=v[[i]]
       args[[1]] = as.name("list")
       fname <- paste("InitErgmTerm.", v[[i]][[1]], sep = "")
-      newInitErgm <- exists(fname, env=.GlobalEnv, mode="function")
+      newInitErgm <- exists(fname, env=formula.env, mode="function")
       v[[i]][[1]] <- as.name(ifelse (newInitErgm, fname, 
                                      paste("InitErgm.", v[[i]][[1]], sep = "")))
     } else { # This term has no arguments
       fname <- paste("InitErgmTerm.", v[[i]], sep = "")
-      newInitErgm <- exists(fname, env=.GlobalEnv, mode="function")
+      newInitErgm <- exists(fname, env=formula.env, mode="function")
       v[[i]] <- call(ifelse (newInitErgm, fname, 
                              paste("InitErgm.", v[[i]], sep = "")))
       model$offset <- c(model$offset,FALSE)
@@ -55,17 +80,17 @@ ergm.getmodel <- function (formula, nw, silent=FALSE, ...) {
       }
       # The above steps are preparing the way to make the function call
       # InitErgm.xxxx(g, m, args, ...)
-      if(!exists(as.character(v[[i]][[1]]),env=.GlobalEnv, mode="function")){
+      if(!exists(as.character(v[[i]][[1]]),env=formula.env, mode="function")){
         stop("The term ", substring(as.character(v[[i]][[1]]),first=10),
              " does not exist. Are you sure you have the right name?\n",
              call. = FALSE)
       }
       if(silent){
        silentwarnings <- capture.output(
-        model <- eval(v[[i]], .GlobalEnv)  #Call the InitErgm function
+        model <- eval(v[[i]], formula.env)  #Call the InitErgm function
        )
       }else{
-       model <- eval(v[[i]], .GlobalEnv)  #Call the InitErgm function
+       model <- eval(v[[i]], formula.env)  #Call the InitErgm function
       }
     } else { # New InitErgmTerms style
       v[[i]][[2]] <- nw
@@ -79,7 +104,7 @@ ergm.getmodel <- function (formula, nw, silent=FALSE, ...) {
           names(v[[i]])[3+j] <- names(dotdotdot)[j]
         }
       }
-      outlist <- eval(v[[i]], .GlobalEnv)  #Call the InitErgm function
+      outlist <- eval(v[[i]], formula.env)  #Call the InitErgm function
       # Now it is necessary to add the output to the model object
       model <- updatemodel.ErgmTerm(model, outlist)
     }
